==> vala-0.1.2.tar.bz2: vala-0.1.2/vala/valadestructor.h <==
/* valadestructor.vala
 *
 * Copyright (C) 2006-2007  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */

#ifndef __VALADESTRUCTOR_H__
#define __VALADESTRUCTOR_H__

#include <glib.h>
#include <glib-object.h>
#include <vala/valasymbol.h>
#include <vala/valacodenode.h>

G_BEGIN_DECLS


#define VALA_TYPE_DESTRUCTOR (vala_destructor_get_type ())
#define VALA_DESTRUCTOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_DESTRUCTOR, ValaDestructor))
#define VALA_DESTRUCTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_DESTRUCTOR, ValaDestructorClass))
#define VALA_IS_DESTRUCTOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_DESTRUCTOR))
#define VALA_IS_DESTRUCTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_DESTRUCTOR))
#define VALA_DESTRUCTOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_DESTRUCTOR, ValaDestructorClass))

typedef struct _ValaDestructorPrivate ValaDestructorPrivate;

/**
 * Represents a class or instance destructor.
 */
struct _ValaDestructor {
	ValaSymbol parent;
	ValaDestructorPrivate * priv;
};
struct _ValaDestructorClass {
	ValaSymbolClass parent;
};

ValaDestructor* vala_destructor_new (ValaSourceReference* source_reference);
ValaBlock* vala_destructor_get_body (ValaDestructor* self);
void vala_destructor_set_body (ValaDestructor* self, ValaBlock* value);
gboolean vala_destructor_get_instance (ValaDestructor* self);
void vala_destructor_set_instance (ValaDestructor* self, gboolean value);
GType vala_destructor_get_type (void);

G_END_DECLS

#endif

==> vala-0.1.5.tar.bz2: vala-0.1.5/vala/valadestructor.h <==
/* valadestructor.vala
 *
 * Copyright (C) 2006-2007  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */

#ifndef __VALA_VALADESTRUCTOR_H__
#define __VALA_VALADESTRUCTOR_H__

#include <glib.h>
#include <glib-object.h>
#include <vala/valasymbol.h>
#include <vala/valacodenode.h>

G_BEGIN_DECLS


#define VALA_TYPE_DESTRUCTOR (vala_destructor_get_type ())
#define VALA_DESTRUCTOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_DESTRUCTOR, ValaDestructor))
#define VALA_DESTRUCTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_DESTRUCTOR, ValaDestructorClass))
#define VALA_IS_DESTRUCTOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_DESTRUCTOR))
#define VALA_IS_DESTRUCTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_DESTRUCTOR))
#define VALA_DESTRUCTOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_DESTRUCTOR, ValaDestructorClass))

typedef struct _ValaDestructorPrivate ValaDestructorPrivate;

/**
 * Represents a class or instance destructor.
 */
struct _ValaDestructor {
	ValaSymbol parent;
	ValaDestructorPrivate * priv;
};
struct _ValaDestructorClass {
	ValaSymbolClass parent;
};

ValaDestructor* vala_destructor_new (ValaSourceReference* source_reference);
ValaBlock* vala_destructor_get_body (ValaDestructor* self);
void vala_destructor_set_body (ValaDestructor* self, ValaBlock* value);
gboolean vala_destructor_get_instance (ValaDestructor* self);
void vala_destructor_set_instance (ValaDestructor* self, gboolean value);
GType vala_destructor_get_type (void);

G_END_DECLS

#endif
